@@ -1,3 +1,4 @@
+use std::borrow::Borrow;
 use std::fmt::Write;
 
 pub trait DisplayPrometheusExt<'b> {
@@ -26,6 +27,19 @@ impl<'a, 'b> PrometheusFormatter<'a, 'b> {
         }
     }
 
+    #[inline]
+    pub fn label_opt<N, V>(self, name: N, value: impl Borrow<Option<V>>) -> Self
+    where
+        N: std::fmt::Display,
+        V: std::fmt::Display,
+    {
+        if let Some(value) = value.borrow() {
+            self.label(name, value)
+        } else {
+            self
+        }
+    }
+
     #[inline]
     pub fn label<N, V>(self, name: N, value: V) -> Self
     where
